This crate provides a derive macro for generating TryFrom<KeyMap> and TryFrom<Vec<KeyMap>> implementations for enums.
The KeyMap derive macro automatically implements the TryFrom<KeyMap> trait for enums,
allowing you to easily convert a KeyMap to an enum variant based on the specified key bindings.
Derive Macros
- KeyMap
- A derive macro that generates keymap configuration logic from enums.